CRSFactory class
A factory class that creates CoordinateReferenceSystems and CoordinateTransforms
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createCoordinateTransform(
CoordinateReferenceSystem source, CoordinateReferenceSystem target) → CoordinateTransform - Create a coordinate transform from source and target CRS
-
createCoordinateTransformFromCodes(
String sourceCode, String targetCode) → Future< CoordinateTransform> - Create a coordinate transform from source and target codes Throws InvalidArgumentException
-
createCRS(
String crsCode) → Future< CoordinateReferenceSystem> - Create a coordinate reference system from a code, e.g., EPSG:3857. At the present time, only EPSG codes are accepted Throws InvalidArgumentException