CoordinateReferenceSystem class
Coordinate Reference System. Holds the associated projection;
Constructors
- CoordinateReferenceSystem()
- CoordinateReferenceSystem.fromProjection(Projection proj)
- CoordinateReferenceSystem.fromWKT(String wkt)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projection ↔ Projection?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wkt ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited