CoordinateTransform class

Transform a point between coordinate reference systems

Constructors

CoordinateTransform()
CoordinateTransform.fromProjection(Projection source, Projection target)

Properties

hashCode int
The hash code for this object.
no setterinherited
isDefined bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceProjection ↔ Projection?
getter/setter pair
targetProjection ↔ Projection?
getter/setter pair

Methods

inverse(Point srcPoint) → Point?
Inverse transform
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transform(Point srcPoint) → Point?
Transform a point

Operators

operator ==(Object other) bool
The equality operator.
inherited